pub struct Utc;Expand description
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).
Using the TimeZone methods
on the UTC struct is the preferred way to construct DateTime<Utc>
instances.
Example
use chrono::{DateTime, TimeZone, Utc};
let dt = DateTime::from_timestamp(61, 0).unwrap();
assert_eq!(Utc.timestamp_opt(61, 0).unwrap(), dt);
assert_eq!(Utc.with_ymd_and_hms(1970, 1, 1, 0, 1, 1).unwrap(), dt);Implementations
Sourceimpl Utc
impl Utc
Sourcepub fn today() -> Date<Utc>
👎Deprecated since 0.4.23: use Utc::now() instead, potentially with .date_naive()
pub fn today() -> Date<Utc>
Utc::now() instead, potentially with .date_naive()Returns a Date which corresponds to the current date.
Sourcepub fn now() -> DateTime<Utc>
pub fn now() -> DateTime<Utc>
Returns a DateTime<Utc> which corresponds to the current date and time in UTC.
See also the similar Local::now() which returns DateTime<Local>, i.e. the local date
and time including offset from UTC.
Example
// Current time in UTC
let now_utc = Utc::now();
// Current date in UTC
let today_utc = now_utc.date_naive();
// Current time in some timezone (let's use +05:00)
let offset = FixedOffset::east_opt(5 * 60 * 60).unwrap();
let now_with_offset = Utc::now().with_timezone(&offset);Trait Implementations
Sourceimpl Offset for Utc
impl Offset for Utc
Sourcefn fix(&self) -> FixedOffset
fn fix(&self) -> FixedOffset
Sourceimpl TimeZone for Utc
impl TimeZone for Utc
Sourcetype Offset = Utc
type Offset = Utc
TimeZone value can be recovered via TimeZone::from_offset.Sourcefn from_offset(_state: &Utc) -> Utc
fn from_offset(_state: &Utc) -> Utc
Sourcefn offset_from_local_date(&self, _local: &NaiveDate) -> LocalResult<Utc>
fn offset_from_local_date(&self, _local: &NaiveDate) -> LocalResult<Utc>
NaiveDate if possible.Sourcefn offset_from_local_datetime(&self, _local: &NaiveDateTime) -> LocalResult<Utc>
fn offset_from_local_datetime(&self, _local: &NaiveDateTime) -> LocalResult<Utc>
NaiveDateTime if possible.Sourcefn offset_from_utc_date(&self, _utc: &NaiveDate) -> Utc
fn offset_from_utc_date(&self, _utc: &NaiveDate) -> Utc
NaiveDate. This cannot fail.Sourcefn offset_from_utc_datetime(&self, _utc: &NaiveDateTime) -> Utc
fn offset_from_utc_datetime(&self, _utc: &NaiveDateTime) -> Utc
NaiveDateTime. This cannot fail.Sourcefn with_ymd_and_hms(
&self,
year: i32,
month: u32,
day: u32,
hour: u32,
min: u32,
sec: u32,
) -> LocalResult<DateTime<Self>>
fn with_ymd_and_hms( &self, year: i32, month: u32, day: u32, hour: u32, min: u32, sec: u32, ) -> LocalResult<DateTime<Self>>
DateTime from year, month, day, time components and current time zone. Read moreSourcefn ymd(&self, year: i32, month: u32, day: u32) -> Date<Self>
fn ymd(&self, year: i32, month: u32, day: u32) -> Date<Self>
with_ymd_and_hms() insteadDate from year, month, day and the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE. Read moreSourcefn ymd_opt(&self, year: i32, month: u32, day: u32) -> LocalResult<Date<Self>>
fn ymd_opt(&self, year: i32, month: u32, day: u32) -> LocalResult<Date<Self>>
with_ymd_and_hms() insteadDate from year, month, day and the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE. Read moreSourcefn yo(&self, year: i32, ordinal: u32) -> Date<Self>
fn yo(&self, year: i32, ordinal: u32) -> Date<Self>
from_local_datetime() with a NaiveDateTime insteadDate from year, day of year (DOY or “ordinal”) and the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE. Read moreSourcefn yo_opt(&self, year: i32, ordinal: u32) -> LocalResult<Date<Self>>
fn yo_opt(&self, year: i32, ordinal: u32) -> LocalResult<Date<Self>>
from_local_datetime() with a NaiveDateTime insteadDate from year, day of year (DOY or “ordinal”) and the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE. Read moreSourcefn isoywd(&self, year: i32, week: u32, weekday: Weekday) -> Date<Self>
fn isoywd(&self, year: i32, week: u32, weekday: Weekday) -> Date<Self>
from_local_datetime() with a NaiveDateTime insteadDate from ISO week date (year and week number), day of the week (DOW) and
the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE.
The resulting Date may have a different year from the input year. Read moreSourcefn isoywd_opt(
&self,
year: i32,
week: u32,
weekday: Weekday,
) -> LocalResult<Date<Self>>
fn isoywd_opt( &self, year: i32, week: u32, weekday: Weekday, ) -> LocalResult<Date<Self>>
from_local_datetime() with a NaiveDateTime insteadDate from ISO week date (year and week number), day of the week (DOW) and
the current time zone.
This assumes the proleptic Gregorian calendar, with the year 0 being 1 BCE.
The resulting Date may have a different year from the input year. Read moreSourcefn timestamp(&self, secs: i64, nsecs: u32) -> DateTime<Self>
fn timestamp(&self, secs: i64, nsecs: u32) -> DateTime<Self>
timestamp_opt() insteadDateTime from the number of non-leap seconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”)
and the number of nanoseconds since the last whole non-leap second. Read moreSourcefn timestamp_opt(&self, secs: i64, nsecs: u32) -> LocalResult<DateTime<Self>>
fn timestamp_opt(&self, secs: i64, nsecs: u32) -> LocalResult<DateTime<Self>>
DateTime from the number of non-leap seconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”)
and the number of nanoseconds since the last whole non-leap second. Read moreSourcefn timestamp_millis(&self, millis: i64) -> DateTime<Self>
fn timestamp_millis(&self, millis: i64) -> DateTime<Self>
timestamp_millis_opt() insteadDateTime from the number of non-leap milliseconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”). Read moreSourcefn timestamp_millis_opt(&self, millis: i64) -> LocalResult<DateTime<Self>>
fn timestamp_millis_opt(&self, millis: i64) -> LocalResult<DateTime<Self>>
DateTime from the number of non-leap milliseconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”). Read moreSourcefn timestamp_nanos(&self, nanos: i64) -> DateTime<Self>
fn timestamp_nanos(&self, nanos: i64) -> DateTime<Self>
DateTime from the number of non-leap nanoseconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”). Read moreSourcefn timestamp_micros(&self, micros: i64) -> LocalResult<DateTime<Self>>
fn timestamp_micros(&self, micros: i64) -> LocalResult<DateTime<Self>>
DateTime from the number of non-leap microseconds
since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”). Read moreSourcefn datetime_from_str(
&self,
s: &str,
fmt: &str,
) -> Result<DateTime<Self>, ParseError>
fn datetime_from_str( &self, s: &str, fmt: &str, ) -> Result<DateTime<Self>, ParseError>
DateTime::parse_from_str or NaiveDateTime::parse_from_str with and_utc() or and_local_timezone() insteadDateTime with the current offset. Read moreSourcefn from_local_date(&self, local: &NaiveDate) -> LocalResult<Date<Self>>
fn from_local_date(&self, local: &NaiveDate) -> LocalResult<Date<Self>>
from_local_datetime() insteadNaiveDate to the timezone-aware Date if possible.Sourcefn from_local_datetime(
&self,
local: &NaiveDateTime,
) -> LocalResult<DateTime<Self>>
fn from_local_datetime( &self, local: &NaiveDateTime, ) -> LocalResult<DateTime<Self>>
NaiveDateTime to the timezone-aware DateTime if possible.Sourcefn from_utc_date(&self, utc: &NaiveDate) -> Date<Self>
fn from_utc_date(&self, utc: &NaiveDate) -> Date<Self>
from_utc_datetime() insteadNaiveDate to the local time.
The UTC is continuous and thus this cannot fail (but can give the duplicate local time).Sourcefn from_utc_datetime(&self, utc: &NaiveDateTime) -> DateTime<Self>
fn from_utc_datetime(&self, utc: &NaiveDateTime) -> DateTime<Self>
NaiveDateTime to the local time.
The UTC is continuous and thus this cannot fail (but can give the duplicate local time).impl Copy for Utc
impl Eq for Utc
impl StructuralPartialEq for Utc